''Control Fourteen Servos.spin
''Demonstrate how to send signals to 14 servos with the Servos object.

CON
   
  _clkmode = xtal1 + pll16x                  ' Crystal feedback & PLL multiplier
  _xinfreq = 5_000_000                       ' 5 MHz crystal

  SERVO_COUNT = 14                           ' Number of servos to control

VAR

  byte pin[SERVO_COUNT]                      ' Array of servo I/O pins
  long servo[SERVO_COUNT]                    ' Array of servo pulse durations
  long pulseCountAddr, pulseCount            ' The servo pulse count

OBJ

  Servos : "Servos for PE Kit"               ' Declare Servos object

PUB testServos | index, position

  '' Initialize all servos to center pulse duration.  Notice that the
  '' duration stored in serov[index] specifies the pulse duration for
  '' the servo connected to pin[index].
  repeat index from 0 to (SERVO_COUNT - 1) 
    pin[index]   := lookupz(index: 4,5,6,7,8,9,10,11,12,14,16,18,19,20) 
    servo[index] := lookupz(index: 0,0,0,0,0,0, 0, 0, 0, 0, 0, 0, 0, 0)
  
  '' Start the servos object, and pass it the addresses of the pin and
  '' pulse duration arrays along with the number of servos the object
  '' will control.  The object returns the address of the variable it
  '' updates when it has completed sending a current pulse cycle.
  pulseCountAddr := servos.start(@pin[0], @servo[0], SERVO_COUNT)

  '' Wait for a 3 s, letting the object deliver center pulses to the servos.
  waitcnt(clkfreq*3 + cnt)

  '' Loop sweeps the servos connected to P4..P7.  Note that the inner 
  '' loop does not update the servo positions until the pulsecount has
  '' increased.  This can be used to synchronize servo position updates. 
  repeat
    repeat position from -1000 to 1000 step 25
      repeat until pulseCount < (pulsecount := long[pulseCountAddr])
      servo[0] := position
      servo[1] := -position
      servo[2] := position/2
      servo[3] := -position/2
      
      